package VMOMI::DvsNetworkRuleDirectionType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
